{% extends 'home.html'%}
{% block body_block%}

<div class='jumbotron'>

    <form action = "" method = "get"> 
    <h3><label >Ask the bot a question: </label> </h3>
    <input type="text" name="n"> 
    <input type="submit" value="submit" > 
    <p><a href="{% url 'answer'%}">click for answer</a></p>
    </form>
</div>

{% endblock %}