{% extends 'swot/swot_base.html'%}
{% block body_block %}

<div class='jumbotron'>


<h2>Purpose detail:</h2>
<p>Purpose: {{purpose_detail.purpose}}</p>

<table class="table table-striped table-dark">  
<tr>
    <th>Strength</th>
    <th>Weaknesses</th>
    <th>Oportinuties</th>
    <th>Threats</th>

</tr>

<tr>
    
<td>{% for s in purpose_detail.s.all%}
<p>{{s.strength}}</p>
{% endfor%}
</td>



<td>{% for s in purpose_detail.s.all%}
<p>{{s.weaknesses}}</p>
{% endfor%}
</td>



<td>{% for s in purpose_detail.s.all%}
<p>{{s.oportinuties}}</p>
{% endfor%}
</td>



<td>{% for s in purpose_detail.s.all%}
<p>{{s.threats}}</p>
{% endfor%}
</td>


</tr>
</table>



<h3>Strategy</h3>
{% for s in purpose_detail.s.all%}
<p>{{s.strategy}}</p>
{% endfor%}


</div>




 <div class="container">
    <p><a class='btn btn-secondary'href="{% url 'swot:update' pk=purpose_detail.pk %}"></a>Update</p>
    
</div>

{% endblock %}





