# Generated by Django 3.0.2 on 2020-04-10 03:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Purpose',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('purpose', models.CharField(max_length=256)),
            ],
        ),
        migrations.CreateModel(
            name='SWOT',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('strength', models.CharField(blank=True, default=None, max_length=256)),
                ('strength_rate', models.PositiveIntegerField(default=0, null=True)),
                ('weaknesses', models.CharField(blank=True, default=None, max_length=256)),
                ('weaknesses_rate', models.PositiveIntegerField(default=0, null=True)),
                ('oportinuties', models.CharField(blank=True, default=None, max_length=256)),
                ('oportinuties_rate', models.PositiveIntegerField(default=0, null=True)),
                ('threats', models.CharField(blank=True, default=None, max_length=256)),
                ('threats_rate', models.PositiveIntegerField(default=0, null=True)),
                ('strategy', models.TextField(blank=True, default=None)),
                ('purpose', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='s', to='swot.Purpose')),
            ],
        ),
    ]
