{% extends 'qary_app/qary_app_base.html'%}
{% block body_block%}

<div class=jumbotron>
   <h2>Welcome to a list of all detail post</h2>
    <h3>Posts detail: </h3>
    <p>Author: {{post_detail.author}}</p>
    <p>Title: {{post_detail.title}}</p>
    <p>{{post_detail.text}}</p>
</div>
{% endblock %}
