{% extends 'home.html'%}
{% block body_block%}

<div class='jumbotron'>
<h3><h2>Your question: </h2>{{Question}}</h3>
<h3><h2>Bot answer: </h2>{{insert}}</h3>
<p><a href="{% url 'question'%}">Ask another question</a></p>
</div>

{% endblock %}