{% extends 'qary_app/qary_app_base.html'%}
{% block body_block%}

<h2>Welcome to a list of all Posts</h2>
<ol>
    {% for p in posts %}
    <h4><li><a href="{{p.id}}">{{p.title}}</a></li></h4>
    {%endfor%}
</ol>

{% endblock %}
