{% extends 'swot/swot_base.html'%}
{% block body_block %}

<div>

<h1>Welcome to a list of all the Purposes!</h1>

<ol>   
    {% for p in purposes %}
    <h3><font size="5" color="#D35400">
      <li><a href="{{p.id}}"><font size="5" color="#D35400">{{p.purpose}}</font></a></li>
  </font>
  </h3>
    {% endfor %}   
</ol>
</div>


{% endblock %}




