{% extends 'swot/swot_base.html'%}
{% block body_block %}

<h1>
    {% if not form.instance.pk%}
    Create Purpose
    {% else %}
    Update Purpose
    {% endif%}
</h1>
<form method="post">
    {% csrf_token %}
    {{ form.as_p }}
    <input type="submit" class="btn btn-secondary" value="Submit">
</form>





{% endblock %}